'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Form = undefined;

var _objectWithoutProperties2 = require('babel-runtime/helpers/objectWithoutProperties');

var _objectWithoutProperties3 = _interopRequireDefault(_objectWithoutProperties2);

var _extends2 = require('babel-runtime/helpers/extends');

var _extends3 = _interopRequireDefault(_extends2);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _helperFunctions = require('./helperFunctions');

var _recompose = require('recompose');

var _Button = require('./Button');

var _Button2 = _interopRequireDefault(_Button);

var _SelectOne = require('./SelectOne');

var _SelectOne2 = _interopRequireDefault(_SelectOne);

var _ = require('.');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var Form = function Form(props) {
  var className = props.className,
      style = props.style,
      values = props.values,
      touched = props.touched,
      errors = props.errors,
      children = props.children,
      handleChange = props.handleChange,
      handleBlur = props.handleBlur,
      handleSubmit = props.handleSubmit,
      handleReset = props.handleReset,
      setFieldValue = props.setFieldValue,
      setFieldTouched = props.setFieldTouched,
      isSubmitting = props.isSubmitting;


  var renderError = function renderError(type) {
    return errors && errors[type] && touched && touched[type] && _react2.default.createElement(
      'div',
      { className: 'form__error' },
      errors[type]
    );
  };

  var renderSelectOneSocket = function renderSelectOneSocket(_ref) {
    var type = _ref.type,
        label = _ref.label,
        options = _ref.options;

    return _react2.default.createElement(
      'div',
      { className: 'form__socket form__select__socket' },
      _react2.default.createElement(
        'div',
        { className: 'form__label form__select__label' },
        (0, _helperFunctions.capitalizeEveryWord)(label)
      ),
      _react2.default.createElement(
        _SelectOne2.default,
        {
          renderTrigger: function renderTrigger(_ref2) {
            var isOn = _ref2.isOn,
                currentOption = _ref2.currentOption,
                getTriggerProps = _ref2.getTriggerProps;
            return _react2.default.createElement(
              _Button2.default,
              (0, _extends3.default)({
                type: 'caretdown',
                isOn: isOn
              }, getTriggerProps({
                className: 'selectone__trigger',
                style: { border: '1px solid #ccc' }
              }), {
                colors: _.buttonStyles.monochrome
              }),
              currentOption ? currentOption.label : ''
            );
          },
          options: options,
          currentOption: values[type],
          onChange: function onChange(value) {
            setFieldValue(type, value);
          },
          transitionType: ['dropdown', 'fade'],
          pivotFrom: 'DOWNRIGHT'
        },
        function (_ref3) {
          var getChildProps = _ref3.getChildProps,
              getChildrenProps = _ref3.getChildrenProps,
              currentOption = _ref3.currentOption,
              toggleIsOn = _ref3.toggleIsOn;
          return _react2.default.createElement(
            'div',
            (0, _extends3.default)({}, getChildrenProps({ style: { width: '25.5rem' } })),
            options.map(function (option) {
              return _react2.default.createElement(
                _Button2.default,
                (0, _extends3.default)({}, getChildProps({
                  option: { value: option.value, label: option.label },
                  onClick: toggleIsOn
                }), {
                  isOn: currentOption.value === option.value,
                  key: option.value
                }),
                option.label
              );
            })
          );
        }
      )
    );
  };
  var renderSubmitButton = function renderSubmitButton() {
    var _ref4 = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

    var label = _ref4.label,
        props = (0, _objectWithoutProperties3.default)(_ref4, ['label']);
    return _react2.default.createElement(
      _Button2.default,
      (0, _extends3.default)({
        invert: true,
        colors: 'surfing',
        onClick: handleSubmit,
        dataTestId: 'submit',
        disabled: isSubmitting,
        style: { width: '24rem', borderRadius: '.25rem' }
      }, props),
      label
    );
  };

  var renderTextInputSocket = function renderTextInputSocket(_ref5) {
    var type = _ref5.type,
        label = _ref5.label,
        sublabel = _ref5.sublabel,
        _ref5$options = _ref5.options,
        options = _ref5$options === undefined ? { required: true, autoFocus: false, autoComplete: '' } : _ref5$options,
        props = (0, _objectWithoutProperties3.default)(_ref5, ['type', 'label', 'sublabel', 'options']);

    return _react2.default.createElement(
      'div',
      (0, _extends3.default)({ className: 'form__socket' }, props),
      _react2.default.createElement('input', {
        id: type,
        className: 'form__socket__input form__socket__input__' + type.toLowerCase(),
        type: 'text',
        required: options.required ? options.required : true,
        autoFocus: options.autoFocus ? options.autoFocus : false,
        value: values[type],
        autoComplete: options.autoComplete ? options.autoComplete : '',
        onChange: handleChange,
        onBlur: function onBlur() {
          return setFieldTouched(type);
        }
      }),
      _react2.default.createElement(
        'div',
        { className: 'form__label form__socket__label' },
        (0, _helperFunctions.capitalizeEveryWord)(label)
      ),
      _react2.default.createElement('div', { className: 'form__socket__bar' }),
      sublabel && _react2.default.createElement(
        'div',
        { className: 'form__socket__sublabel' },
        sublabel
      ),
      renderError(type)
    );
  };

  var renderGroup = function renderGroup(_ref6) {
    var label = _ref6.label,
        renderChildren = _ref6.renderChildren;
    return _react2.default.createElement(
      'div',
      { className: 'form__group' },
      _react2.default.createElement(
        'div',
        { className: 'form__label form__group__label' },
        label
      ),
      _react2.default.createElement(
        'div',
        { className: 'form__children form__group__children' },
        renderChildren()
      )
    );
  };
  var renderCheckboxSocket = function renderCheckboxSocket(_ref7) {
    var label = _ref7.label,
        type = _ref7.type;
    return _react2.default.createElement(
      'div',
      { className: 'form__checkbox' },
      _react2.default.createElement(
        'div',
        { className: 'form__label form__checkbox__label' },
        label
      ),
      _react2.default.createElement('input', {
        id: type,
        className: 'form__checkbox__input',
        type: 'checkbox',
        checked: values[type],
        onChange: handleChange
      })
    );
  };

  return _react2.default.createElement(
    'form',
    {
      onSubmit: handleSubmit,
      className: className ? 'form ' + className : 'form',
      style: style
    },
    children({
      renderTextInputSocket: renderTextInputSocket,
      renderSelectOneSocket: renderSelectOneSocket,
      renderCheckboxSocket: renderCheckboxSocket,
      renderGroup: renderGroup,
      renderSubmitButton: renderSubmitButton
    }),
    errors.firebase && _react2.default.createElement(
      'div',
      {
        'data-testid': 'registeraccountmodal-formerror-firebase',
        className: 'input-feedback'
      },
      'error!',
      errors.firebase
    ),
    _react2.default.createElement('input', { type: 'submit', style: { visibility: 'hidden', height: 0, width: 0 } })
  );
};

exports.Form = Form;
Form.defaultProps = {
  handleSubmit: function handleSubmit() {
    return console.log('Form: handleSubmit');
  },
  style: {}
};
var enhance = (0, _recompose.compose)((0, _recompose.onlyUpdateForKeys)(['values', 'touched', 'errors', 'children']), (0, _recompose.lifecycle)({
  componentDidMount: function componentDidMount() {
    var onMount = this.props.onMount;

    onMount && onMount();
  },
  componentWillUnmount: function componentWillUnmount() {
    var onUnmount = this.props.onUnmount;

    onUnmount && onUnmount();
  }
}));

exports.default = enhance(Form);